@@ -23,10 +23,12 @@
 
 #include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
+#include <glom/bakery/app_withdoc_gtk.h>
+
 //TODO: Remove this when maemomm's gtkmm has been updated. 7th September 2009.
 #ifdef GLOM_ENABLE_MAEMO
-//Because earlier versions of gtkmm/enums.h did not include this, so  
-//GTKMM_MAEMO_EXTENSIONS_ENABLED was not defined, 
+//Because earlier versions of gtkmm/enums.h did not include this, so
+//GTKMM_MAEMO_EXTENSIONS_ENABLED was not defined,
 //leading to a compiler error in hildonmm/button.h
 #include <gtkmmconfig.h>
 #include <gtkmm/enums.h>
@@ -35,7 +37,6 @@
 #include <glom/navigation/maemo/pickerbutton_table.h>
 #endif //GLOM_ENABLE_MAEMO
 
-#include <glom/bakery/app_withdoc_gtk.h>
 #include <glom/frame_glom.h>
 
 
@@ -52,15 +53,24 @@ namespace Glom
 {
 
 class Window_Translations;
+class Dialog_ProgressCreating; //TODO: Rename this because it's not just about creating databases.
 
-class App_Glom : public GlomBakery::App_WithDoc_Gtk
+class Application : public GlomBakery::App_WithDoc_Gtk
 {
 public:
-  App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
-  virtual ~App_Glom();
+  static const char* glade_id;
+  static const bool glade_developer;
+
+  Application(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
+  virtual ~Application();
 
   virtual bool init(const Glib::ustring& document_uri = Glib::ustring()); //override
 
+  /**
+   * @param restore Whether @a document_uri is a .tar.gz backup file to restore.
+   */
+  bool init(const Glib::ustring& document_uri, bool restore);
+
   //virtual void statusbar_set_text(const Glib::ustring& strText);
   //virtual void statusbar_clear();
 
@@ -89,6 +99,10 @@ public:
   void update_userlevel_ui();
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
+  /** Enable/disable UI elements depending on whether a table is loaded.
+   */
+  void update_table_sensitive_ui();
+
   AppState::userlevels get_userlevel() const;
 
   void fill_menu_tables();
@@ -98,6 +112,7 @@ public:
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void do_menu_developer_fields(Gtk::Window& parent, const Glib::ustring table_name);
   void do_menu_developer_relationships(Gtk::Window& parent, const Glib::ustring table_name);
+  bool do_restore_backup(const Glib::ustring& backup_uri);
 #endif //GLOM_ENABLE_CLIENT_ONLY
 
   ///Whether to show the generated SQL queries on stdout, for debugging.
@@ -106,7 +121,22 @@ public:
   ///Whether to show the generated SQL queries on stdout, for debugging.
   void set_show_sql_debug(bool val = true);
 
-  static App_Glom* get_application();
+  void show_table_details(const Glib::ustring& table_name, const Gnome::Gda::Value& primary_key_value);
+  void show_table_list(const Glib::ustring& table_name);
+
+  /** Print the named report for the current table.
+   */
+  void print_report(const Glib::ustring& report_name);
+
+  /** Print the current layout for the current table.
+   */
+  void print_layout();
+
+  /** Offer the user the UI to add a new record,
+   */
+  void start_new_record();
+
+  static Application* get_application();
 
 protected:
   virtual void ui_warning_load_failed(int failure_code = 0); //Override.
@@ -131,7 +161,7 @@ private:
   void on_menu_help_contents();
 #endif //GLOM_ENABLE_MAEMO
 
-  /** Check that the file's hosting mode is supported by this build and 
+  /** Check that the file's hosting mode is supported by this build and
    * tell the user if necessary.
    */
   bool check_document_hosting_mode_is_supported(Document* document);
@@ -147,6 +177,8 @@ private:
   void on_menu_developer_translations();
   void on_menu_developer_active_platform_normal();
   void on_menu_developer_active_platform_maemo();
+  void on_menu_developer_export_backup();
+  void on_menu_developer_restore_backup();
   void on_menu_developer_show_layout_toolbar();
 
   void on_window_translations_hide();
@@ -156,9 +188,10 @@ private:
 
   Document* on_connection_pool_get_document();
 
-  bool recreate_database(bool& user_cancelled); //return indicates success.
+  bool recreate_database_from_example(bool& user_cancelled); //return indicates success.
+  bool recreate_database_from_backup(const Glib::ustring& backup_uri, bool& user_cancelled); //return indicates success.
   void stop_self_hosting_of_document_database();
-  
+
   void on_connection_avahi_begin();
   void on_connection_avahi_progress();
   void on_connection_avahi_done();
@@ -175,8 +208,10 @@ private:
   virtual void document_history_add(const Glib::ustring& file_uri); //overridden.
 
   virtual void new_instance(const Glib::ustring& uri = Glib::ustring()); //Override
-  
+
   void on_connection_close_progress();
+  void on_connection_save_backup_progress();
+  void on_connection_convert_backup_progress();
 
 #ifndef G_OS_WIN32
   void open_browsed_document(const EpcServiceInfo* server, const Glib::ustring& service_name);
@@ -190,8 +225,9 @@ private:
 
   Glib::RefPtr<Gtk::ActionGroup> m_refActionGroup_Others;
 
-  typedef std::list< Glib::RefPtr<Gtk::Action> > type_listActions; 
+  typedef std::list< Glib::RefPtr<Gtk::Action> > type_listActions;
   type_listActions m_listDeveloperActions; //Only enabled when in developer mode.
+  type_listActions m_listTableSensitiveActions; // Only enabled when a table is loaded.
   Glib::RefPtr<Gtk::Action> m_action_mode_data, m_action_mode_find;
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   Glib::RefPtr<Gtk::Action> m_action_developer_users;
@@ -233,6 +269,8 @@ private:
   Document::HostingMode m_ui_save_extra_newdb_hosting_mode;
 
   Gtk::MessageDialog* m_avahi_progress_dialog;
+  Dialog_ProgressCreating* m_dialog_progess_save_backup;
+  Dialog_ProgressCreating* m_dialog_progess_convert_backup;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   // This is set to the URI of an example file that is loaded to be able to
@@ -240,7 +278,7 @@ private:
   // document_history_add().
   Glib::ustring m_example_uri;
 
-  //A temporary store for the username/password if 
+  //A temporary store for the username/password if
   //we already asked for them when getting the document over the network,
   //so we can use them again when connecting directly to the database:
   Glib::ustring m_temp_username, m_temp_password;
