@@ -18,7 +18,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "fieldformatting.h"
 #include <libglom/data_structure/layout/fieldformatting.h>
+#include <libglom/data_structure/glomconversions.h>
 #include <glibmm/i18n.h>
 
 const guint MULTILINE_TEXT_DEFAULT_HEIGHT_LINES = 6;
@@ -28,10 +30,12 @@ namespace Glom
 
 FieldFormatting::FieldFormatting()
 : m_choices_restricted(false),
+  m_choices_restricted_as_radio_buttons(false),
   m_choices_custom(false),
   m_choices_related(false),
   m_text_format_multiline(false),
-  m_text_multiline_height_lines(MULTILINE_TEXT_DEFAULT_HEIGHT_LINES)
+  m_text_multiline_height_lines(MULTILINE_TEXT_DEFAULT_HEIGHT_LINES),
+  m_horizontal_alignment(HORIZONTAL_ALIGNMENT_AUTO)
 {
 }
 
@@ -40,6 +44,7 @@ FieldFormatting::FieldFormatting(const FieldFormatting& src)
   m_numeric_format(src.m_numeric_format),
   m_choices_custom_list(src.m_choices_custom_list),
   m_choices_restricted(src.m_choices_restricted),
+  m_choices_restricted_as_radio_buttons(src.m_choices_restricted_as_radio_buttons),
   m_choices_custom(src.m_choices_custom),
   m_choices_related(src.m_choices_related),
   m_text_format_multiline(src.m_text_format_multiline),
@@ -47,6 +52,7 @@ FieldFormatting::FieldFormatting(const FieldFormatting& src)
   m_text_font(src.m_text_font),
   m_text_color_foreground(src.m_text_color_foreground),
   m_text_color_background(src.m_text_color_background),
+  m_horizontal_alignment(src.m_horizontal_alignment),
   m_choices_related_field(src.m_choices_related_field),
   m_choices_related_field_second(src.m_choices_related_field_second)
 {
@@ -62,6 +68,7 @@ bool FieldFormatting::operator==(const FieldFormatting& src) const
     (m_numeric_format == src.m_numeric_format) &&
     (m_choices_custom_list == src.m_choices_custom_list) &&
     (m_choices_restricted == src.m_choices_restricted) &&
+    (m_choices_restricted_as_radio_buttons == src.m_choices_restricted_as_radio_buttons) &&
     (m_choices_custom == src.m_choices_custom) &&
     (m_choices_related == src.m_choices_related) &&
     (m_choices_related_field == src.m_choices_related_field) &&
@@ -70,7 +77,8 @@ bool FieldFormatting::operator==(const FieldFormatting& src) const
     (m_text_multiline_height_lines == src.m_text_multiline_height_lines) &&
     (m_text_font == src.m_text_font) &&
     (m_text_color_foreground == src.m_text_color_foreground) &&
-    (m_text_color_background == src.m_text_color_background);
+    (m_text_color_background == src.m_text_color_background) && 
+    (m_horizontal_alignment == src.m_horizontal_alignment);
 }
 
 
@@ -82,6 +90,7 @@ FieldFormatting& FieldFormatting::operator=(const FieldFormatting& src)
 
   m_choices_custom_list = src.m_choices_custom_list;
   m_choices_restricted = src.m_choices_restricted;
+  m_choices_restricted_as_radio_buttons = src.m_choices_restricted_as_radio_buttons;
   m_choices_custom = src.m_choices_custom;
   m_choices_related = src.m_choices_related;
   m_choices_related_field = src.m_choices_related_field;
@@ -92,6 +101,7 @@ FieldFormatting& FieldFormatting::operator=(const FieldFormatting& src)
   m_text_font = src.m_text_font;
   m_text_color_foreground = src.m_text_color_foreground;
   m_text_color_background = src.m_text_color_background;
+  m_horizontal_alignment = src.m_horizontal_alignment;
 
 //g_warning("FieldFormatting::operator=: m_choices_related_relationship=%s, src.m_choices_related_relationship=%s", m_choices_related_relationship->c_str(), src.m_choices_related_relationship->c_str());
   return *this;
@@ -141,6 +151,18 @@ Glib::ustring FieldFormatting::get_text_format_color_foreground() const
   return m_text_color_foreground;
 }
 
+Glib::ustring FieldFormatting::get_text_format_color_foreground_to_use(const Gnome::Gda::Value& value) const
+{
+  if(m_numeric_format.m_alt_foreground_color_for_negatives)
+  {
+    //TODO: Use some other color if the alternative color is too similar to the foreground color.
+    if(Conversions::get_double_for_gda_value_numeric(value) < 0)
+      return NumericFormat::get_alternative_color_for_negatives();
+  }
+
+  return m_text_color_foreground;
+}
+
 void FieldFormatting::set_text_format_color_background(const Glib::ustring& color)
 {
   m_text_color_background = color;
@@ -151,6 +173,16 @@ Glib::ustring FieldFormatting::get_text_format_color_background() const
   return m_text_color_background;
 }
 
+void FieldFormatting::set_horizontal_alignment(HorizontalAlignment alignment)
+{
+  m_horizontal_alignment = alignment;
+}
+
+FieldFormatting::HorizontalAlignment FieldFormatting::get_horizontal_alignment() const
+{
+  return m_horizontal_alignment;
+}
+
 bool FieldFormatting::get_has_choices() const
 {
   return ( m_choices_related && get_has_relationship_name() && !m_choices_related_field.empty() ) ||
@@ -167,14 +199,16 @@ void FieldFormatting::set_choices_custom(const type_list_values& choices)
   m_choices_custom_list = choices;
 }
 
-bool FieldFormatting::get_choices_restricted() const
+bool FieldFormatting::get_choices_restricted(bool& as_radio_buttons) const
 {
+  as_radio_buttons = m_choices_restricted_as_radio_buttons;
   return m_choices_restricted;
 }
 
-void FieldFormatting::set_choices_restricted(bool val)
+void FieldFormatting::set_choices_restricted(bool val, bool as_radio_buttons)
 {
   m_choices_restricted = val;
+  m_choices_restricted_as_radio_buttons = as_radio_buttons;
 }
 
 bool FieldFormatting::get_has_custom_choices() const
